{% extends "admin/change_form.html" %}
{% load i18n admin_urls admin_static admin_modify %}

{% block bodyclass %}{{ block.super }} export-form{% endblock %}

{% if not is_popup %}
{% block breadcrumbs %}
<div class="breadcrumbs">
<a href="{% url 'admin:index' %}">{% trans 'Home' %}</a>
&rsaquo; <a href="{% url 'admin:app_list' app_label=opts.app_label %}">{{ opts.app_config.verbose_name }}</a>
&rsaquo; {% if has_change_permission %}<a href="{% url opts|admin_urlname:'changelist' %}">{{ opts.verbose_name_plural|capfirst }}</a>{% else %}{{ opts.verbose_name_plural|capfirst }}{% endif %}
&rsaquo; {% trans 'Export' %} {{ opts.verbose_name|capfirst }}
</div>
{% endblock %}
{% endif %}

{% block submit_buttons_bottom %}
<div class="submit-row">
    <input type="submit" value="{% trans 'Export' %}" class="default" name="export" />
</div>
{% endblock %}

